
def glob_paths(src_dir, wildcards=["**/*"]):
    """通过通配符, 读取目录下多种后缀名的文件, 比如["**/*.txt", "**/*.jpg"]。
    Args:
        path: path.Path()类型。文件夹路径。
        wildcards: str list类型。通配符列表, 如["**/*.txt", "**/*.jpg"]。
    Returns:
        返回文件路径list列表, 路径数据类型为pathlib.Path。
    """
    paths = []
    for w in wildcards:
        paths.extend(src_dir.glob(w))
    return paths



import os
import click


plugin_folder = os.path.join(os.path.dirname(__file__), 'commands')


class MyCLI(click.MultiCommand):
    def list_commands(self, ctx):
        rv = []
        for filename in os.listdir(plugin_folder):
            if filename.endswith('.py'):
                rv.append(filename[:-3])
        rv.sort()
        return rv

    def get_command(self, ctx, name):
        ns = {}
        fn = os.path.join(plugin_folder, name + '.py')
        with open(fn) as f:
            code = compile(f.read(), fn, 'exec')
            eval(code, ns, ns)
        return ns['cli']


cli = MyCLI(
    help="This tool's subcommands are loaded from a plugin folder dynamically.")


if __name__ == '__main__':
    cli()



from aigcfile.image.rename import ImageRename


class Rename(object):

    def __init__(self, filetype):
        self.filetype = filetype

    def __call__(self, mode="sequence", *args, **kwargs):
        if self.filetype == "image":
            rename = ImageRename(mode)
        rename(*args, **kwargs)



import shutil
from aigcfile.image.rename import *


################################################################################
# ImageRename()
################################################################################
print("\nImageRename(): ")
data_dir = "data/images"
src_dir = "tmp/images"
if pathlib.Path(src_dir).exists():
    shutil.rmtree(src_dir)
shutil.copytree(data_dir, src_dir)

rename = ImageRename(mode="sequence")
rename(src_dir, suffix=".jpg", verbose=True)



import ast
import click
from aigcfile.clis.click.utils.datatype import PythonLiteralOption
from aigcfile.module.write import Write


@click.command('write')
@click.option('--filetype', "-t", default="text", help='要处理的文件类型, 可选值: image')
@click.option('--mode', "-m", default="same", help='重命名模式, 可选值: sequence')
@click.option('--src_dir', "-s", default="data/text", help='输入视频文件或所在文件夹')
@click.option('--string', default="your content description", help='添加的文本内容')
@click.option('--wildcards', "-w", cls=PythonLiteralOption, default="['.txt', '.TXT']", help='哪些源文件将被索引')
def cli(filetype, *args, **kwargs):
    """文件重命名。
    aigcfile write -s tmp/text -t text -m same -w '[".txt", ".TXT"]'
    """
    print("被索引的源文件类型{}: {}".format(filetype, kwargs["wildcards"]))
    writer = Write(filetype)
    writer(*args, **kwargs)



from aigcfile.text.write import TextWrite


class Write(object):

    def __init__(self, filetype):
        self.filetype = filetype

    def __call__(self, mode="same", *args, **kwargs):
        if self.filetype == "text":
            writer = TextWrite(mode)
        writer(*args, **kwargs)



import ast
import click


class PythonLiteralOption(click.Option):
    """用于click输入list"""

    def type_cast_value(self, ctx, value):
        try:
            return ast.literal_eval(value)
        except:
            raise click.BadParameter(value)



import ast
import click
from aigcfile.clis.click.utils.datatype import PythonLiteralOption
from aigcfile.module.rename import Rename


@click.command('rename')
@click.option('--filetype', "-t", default="image", help='要处理的文件类型, 可选值: image')
@click.option('--mode', "-m", default="sequence", help='重命名模式, 可选值: sequence')
@click.option('--src_dir', "-s", default="data/images", help='输入视频文件或所在文件夹')
@click.option('--dst_dir', "-d", default="", help='输出视频文件或所在文件夹')
@click.option('--suffix', default=".png", help='输出文件后缀名')
@click.option('--wildcards', "-w", cls=PythonLiteralOption, default="['.png', '.PNG', '.jpg', '.JPG', '.jpeg', '.JPEG']", help='哪些源文件将被索引')
@click.option('--verbose', default=True, help='是否显示tqdm进度条')
@click.option('--name', default="{:0>8d}", help='输出文件命名格式')
@click.option('--remove', default=False, help='清空dst指向的目录或文件')

def cli(filetype, *args, **kwargs):
    """文件重命名。
    aigcfile rename -s tmp/images -t image -m sequence -w '[".png", ".PNG", ".jpg", ".JPG", ".jpeg", ".JPEG"]'
    """
    print("被索引的源文件类型{}: {}".format(filetype, kwargs["wildcards"]))
    rename = Rename(filetype)
    rename(*args, **kwargs)



import pathlib
import cv2
from tqdm import tqdm
from aigcfile.utils.globfile import glob_paths


class TextWrite(object):
    """图片文件修改名称, 特别是修改后缀名后, 一般要重新编码。
    """

    def __init__(self, mode="same"):
        self.mode = mode

    def stem(self, src_path, dst_path):
        """只是修改文件名, 不修改后缀
        """
        dst_path = dst_path.parent / f"{dst_path.stem}.{src_path.suffix}"
        src_path.rename(dst_path)

    def name(self, src_path, dst_path):
        """修改文件名称, src和dst后缀名称不同时, 重新编码.
        """
        if src_path.suffix == dst_path.suffix:
            src_path.rename(dst_path)
        else:
            image = cv2.imread(str(src_path))
            cv2.imwrite(str(dst_path), image)
            src_path.unlink()

    def same(self, src_dir, string="weiwenying, chinese man, chinese william, china, 30 year old, middle-aged man, ", wildcards=[".txt", ".TXT"], *args, **kwargs):
        """在当前目录内, 对文件进行重新命名, 名称格式由name指定, 输出格式由suffix指定。
        """
        wildcards = ["*{}".format(s) for s in wildcards]
        src_dir = pathlib.Path(src_dir)
        sub_dirs = [x for x in src_dir.glob("*/**") if x.is_dir()]
        sub_dirs.append(src_dir)
        print(sub_dirs)

        for sub_dir in sub_dirs:
            src_paths = sorted(glob_paths(sub_dir, wildcards))
            for src_path in tqdm(src_paths, desc=str(sub_dir)):
                with open(src_path, "r+") as f:
                    content = f.read()
                    f.seek(0, 0)
                    f.write(string + content)

    def __call__(self, *args, **kwargs):
        if self.mode == "same":
            self.same(*args, **kwargs)
        else:
            raise Exception("mode '{}' not suport!".format(self.mode))



import pathlib
import cv2
from tqdm import tqdm
from aigcfile.utils.globfile import glob_paths


class ImageRename(object):
    """图片文件修改名称, 特别是修改后缀名后, 一般要重新编码。
    """

    def __init__(self, mode="sequence"):
        self.mode = mode
    
    def stem(self, src_path, dst_path):
        """只是修改文件名, 不修改后缀
        """
        dst_path = dst_path.parent / f"{dst_path.stem}.{src_path.suffix}"
        src_path.rename(dst_path)

    def name(self, src_path, dst_path):
        """修改文件名称, src和dst后缀名称不同时, 重新编码.
        """
        if src_path.suffix == dst_path.suffix:
            src_path.rename(dst_path)
        else:
            image = cv2.imread(str(src_path))
            cv2.imwrite(str(dst_path), image)
            src_path.unlink()

    def sequence(self, src_dir, name="{:0>8d}", suffix=".png", wildcards=[".png", ".PNG", ".jpg", ".JPG", ".jpeg", ".JPEG"], verbose=True, *args, **kwargs):
        """在当前目录内, 对文件进行重新命名, 名称格式由name指定, 输出格式由suffix指定。
        """
        name = name + "{}"
        wildcards = ["*{}".format(s) for s in wildcards]
        src_dir = pathlib.Path(src_dir)
        sub_dirs = [x for x in src_dir.glob("*/**") if x.is_dir()]
        sub_dirs.append(src_dir)

        for sub_dir in sub_dirs:
            src_paths = sorted(glob_paths(sub_dir, wildcards))
            # if verbose:
            #     src_paths = tqdm(src_paths, desc=str(sub_dir))

            for i, src_path in enumerate(tqdm(src_paths, desc=str(sub_dir))):
                dst_path = src_path.parent / name.format(i, suffix)
                if dst_path.exists():
                    j = src_paths.index(dst_path)
                    src_paths[i], src_paths[j] = src_paths[j], src_paths[i]
                else:
                    self.name(src_path, dst_path)

    def __call__(self, *args, **kwargs):
        if self.mode == "sequence":
            self.sequence(*args, **kwargs)
        else:
            raise Exception("mode '{}' not suport!".format(self.mode))
